@@ -35,7 +35,7 @@ static void fire_watchers(pTHX_ IV idx, SV *new_val);
 static OP* pp_slot_get(pTHX) {
     dSP;
     IV idx = PL_op->op_targ;
-    XPUSHs(g_slots[idx]);
+    PUSHs(g_slots[idx]);  /* Stack already extended by call */
     RETURN;
 }
 
